---
title: CNCF TAG Contributor Strategy Charter
linkTitle: Charter
---

Primary Authors: Paris Pittman, Josh Berkus  

Reviewed and/or contributed to by:  
* Matt Klein
* Matt Farina  
* Carolyn Van Slyck  
* April Nassi
* Matt Jarvis
* Gerred Dillon
* Ken Owens
* Cheryl Hung
* Amye Scavarda Perrin
* Ihor Dvoretskyi
* Liz Rice
* Sarah Allen

## Introduction
This charter describes the operations of the CNCF Technical Advisory Group (TAG)
Contributor Strategy. This TAG is responsible for contributor experience,
sustainability, governance, and openness guidance to help CNCF community groups
and projects with their own contributor strategies for a healthy project.

Our initial three stakeholders:  
1 - CNCF projects and their contributors/maintainers,  
2 - End Users in the broader community and member companies,  
3 - TOC

## Mission
Consistent with the CNCF TAG definition, the mission of CNCF TAG Contributor
Strategy is to collaborate on strategies related to building, scaling, and
retaining contributor communities, including (people) governance, 
communications, operations, and tools. We want to help grow flourishing, 
sustainable communities with smooth journeys throughout their CNCF project 
lifecycle.   
To do that we will:
* **Create intentional space.** Form a "Maintainers Circle" (name may
  change) comprised of those interested in growing their projects and joining
  fellow maintainers in related cross project discussions.
* **Listen and Advise.** Create informational and training resources including
guides, tutorials and templates of best practices, trade-offs, strategies,
building and participating in scalable contributor communities.
* **Evaluate and Foster.** Helping the TOC with assessments and due diligence of
prospective new projects by developing community graduation criteria check
points for rolling feedback and guidance.
* **Educate and Engage.** Providing guidance to end users on how to engage with
 contributors and vice versa.

#### In scope:
The following, non exhaustive list of activities and deliverables are
in-scope for the TAG:
* Definition of a contributor. This is helpful across projects for metrics and
establishing guidelines, programs, and workflows.
* Contributor and goverance related proposed/suggested/modified project 
lifecycle requirements for graduation or incubation
* “Contributing health checks”/’community health checks’ (name tbd) for project
evaluations at graduation time  
* Webinars, meetings, and other events to engage with the end user and CNCF 
project community on upstream contributing trainings and engagement programs.  
* Development of guidelines, documents for project governance, recruiting and
retaining contributor communities, mentorship, and project maturity.
* Collection of current state of contributor strategies and governance models
via surveys, GB reps, and Maintainers Circle (Example: what is the project doing
  now, challenges, gaps)

#### Out of scope
* The day to day operations of CNCF TAGs, Kubernetes SIGs, or any community 
group of CNCF or its respective projects of any graduation level.
* The creation and approval of CNCF TAGs or other community groups; we will
offer advice but the responsibility lies on the TOC for those matters.
* CNCF operations and marketing initiatives such as: product review/demo
webinars, kubecon event planning, branding, stickers, swag, etc
* Licensing and legal matters
* Testing


## Current Roadmap
In no particular order,
* Launch the maintainers circle and build community 
  * Training and discussion: inclusive language, code of conduct, code 
  reviewing, leadership, and more
* Continue making recommendations to TOC for project lifecycle milestones as it 
relates to contributor strategy and governance topics (example: multi-org 
contributing requirement, community management, etc)
* Create a project template repo for projects to use as they see fit in a fork 
all or some approach (example: CONTRIBUTING.md, CONTRIBUTOR-LADDER.md templates)


*Possible future roadmap projects*  
If you see something here that interests you, join us and start it:  
* Contributor metrics and definitions  
* Automation and self service for contributors, community GitOps

## Governance
This TAGs topic requires cross collaboration between end users, CNCF TAGs, and
CNCF projects of all graduation levels.

This TAG should be populated and governed by reps from CNCF projects that want
to create and run intentional contributor experience programs, a rep(s) from the
end user committee, and the TOC liaison(s). While the TAG reps do not need to be
core maintainers, they do need to have a drive for making things better for
contributors and end users. We welcome industry experts and academics in
relevant working groups!

Conduct public monthly meetings as a large group and working groups that form
will have their own meetings. (see #Meetings and Decisions for more)

Check in with the TOC on a monthly basis for a quick overview and challenges
during a public TOC meeting.

### Members

Members are active participants in the work of the TAG who are entitled to vote
in any TAG decisions that require a vote.  Any contributor to the TAG is
eligible to become a member after participating in the work of the TAG for at
least three months.

In order to prevent the TAG from becoming unbalanced, it will have the following
limits on who can be a voting member:

Up to one from each participating Incubating or Sandbox CNCF project
Up to two from each Graduated CNCF project
One from each TAG-ContribStrat Working Group, generally the lead for that WG
No more than ⅓ of members from the same employer

If a contributor would be entitled to be a member, but are restricted because of
the above limits, they are a non-voting member who may participate in meetings
but cannot vote.

Members who are no longer participating actively in the TAG (including both WG
  work and the regular meetings) will step down from membership.

#### Leadership

- [Chairs](/README.md#tag-chairs)
- [Tech Leads](/README.md#tech-leads)
- [TOC Liaisons](/README.md#toc-liaisons)
- [Emeritus Leads](/README.md#emeritus-leads)

In accordance with the terms and roles laid out in [cncf-tags.md](https://github.com/cncf/toc/blob/main/tags/cncf-tags.md)

The TOC will also appoint 3 [Chairs](https://github.com/cncf/toc/blob/main/tags/cncf-tags.md#chair)

### Meetings and Decisions

Most TAG work will be carried out without requiring any kind of regular meeting
or vote. The TAG will have a regular meeting, bi-weekly, at which the
membership may vote on the following items as the come up:

* Addition of new members or removal of inactive ones
* Approval of new working groups and retirement of completed/inactive ones
* Approval of reports to be delivered to the TOC
* Approval of formal recommendations to a CNCF project or about that project to
the TOC
* Approval or deprecation of guidelines and documents

### Bootstrapping

Initially, the TOC shall appoint three members in order to launch the TAG

## Reach out!
Mailing List: [tag-contributor-strategy](mailto:tag-contributor-strategy@lists.cncf.io)
mailer at [lists.cncf.io](https://lists.cncf.io)  
[Meeting Notes](https://docs.google.com/document/d/1Xjw-yAqidQW67zv7OfMRErsfCotc-mfQ_248Te_YL0g/edit#heading=h.252i9x89qe0d)  
Slack channel: [#tag-contributor-strategy]  
Public Meetings: Go to [the CNCF calendar](https://www.cncf.io/calendar/) and enter "TAG Contributor Strategy" in the search box to see our meetings


[cncf-tags.md]: https://github.com/cncf/toc/blob/main/tags/cncf-tags.md
[tag-contributor-strategy]: mailto:tag-contributor-strategy@lists.cncf.io
[lists.cncf.io]: https://lists.cncf.io
[Meeting Notes]: https://docs.google.com/document/d/1Xjw-yAqidQW67zv7OfMRErsfCotc-mfQ_248Te_YL0g/edit#heading=h.252i9x89qe0d
